package com.cool.bang.modules.mysql.service;

import com.alibaba.druid.util.StringUtils;
import com.cool.bang.modules.mysql.domain.*;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalFlow;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalNode;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalRecord;
import com.cool.bang.modules.oracle.domain.OracleApprovalRecord;
import com.cool.bang.modules.oracle.domain.Refund;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 *
 *
 * @author PeiZhi Guo
 * 2023-4-8 10:02
 */
@Service
public class RefundService extends BaseService {

    @Transactional
    public void execute() {
        long startTime = System.currentTimeMillis();
        System.out.println(">>>>>>>>>>>>>>>>>>" + "导入退款记录开始执行，" + startTime);

        // 获取结束节点
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(6); //合同退款
        ApprovalNode endNode = new ApprovalNode();
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        for (ApprovalNode node : approvalNodeList) {
            if (node.getNumber() == 4) {
                endNode = node;
            }
        }

        List<Refund> refunds = oracleMapper.selectRefundInfo();

        for (Refund item : refunds) {
            com.cool.bang.modules.mysql.domain.Refund refund = new com.cool.bang.modules.mysql.domain.Refund();
            refund.setBusinessNumber(item.getBusinessNumber());
            refund.setContractNumber(item.getContractNumber());
            refund.setBuyer(item.getBuyer());
            refund.setRefundAmount(item.getRefundAmount());
            refund.setCreateTime(item.getCreateTime());

            // 企业信息
            Org org = orgMapper.selectOrgByMisid(item.getMisId());
            if (org == null || org.getId() == null) {
                throw new RuntimeException("开发单位异常");
            }
            refund.setOrgId(org.getId());
            refund.setOrgName(org.getOrgName());

            // 楼幢信息
            BuildingAccount building = buildingAccountMapper.selectByBuildingNumber(item.getBuildingNumber());
            if (building != null && building.getId() != null) {
                refund.setBuildingAccountId(building.getId());
                refund.setBuildingName(building.getBuildingName());
            }

            // 项目信息
            ProjectAccount project = projectAccountMapper.selectByAregid(item.getAregId());
            refund.setProjectAccountId(project.getId());
            refund.setProjectName(project.getProjectName());
            refund.setProjectNumber(project.getProjectNumber());

            // 收款账户信息
            refund.setCollectionBank(item.getCollectionBank());
            refund.setCollectionName(item.getCollectionName());
            refund.setCollectionAccount(item.getCollectionAccount());

            // 付款账户信息
            if (StringUtils.isEmpty(item.getAppropriationAccount())) {
                continue;
            }
            Account account = accountMapper.selectByAccountNO(item.getAppropriationAccount());
            refund.setAccountId(account.getId());
            refund.setAccountType(account.getType());
            refund.setAppropriationAccount(account.getAccount());
            refund.setAppropriationBank(account.getBankName());
            refund.setBankCode(account.getBankCode());

            // 退款状态
            refund.setAppropriationStatus(item.getIsRefund());

            // 合同
            refund.setContractNumber(item.getContractNumber());
            Contract contract = contractMapper.selectByContractNumber(item.getContractNumber());
            if (contract != null && contract.getId() != null) {
                refund.setContractId(contract.getId());
                refund.setHouseAddress(contract.getHouseAddress());
            }

            // 如果是流程结束
            if (item.getFlowState().equals(0)) {
                refund.setBusinessState(3);
            }
            if (item.getFlowState().equals(1) && item.getFlowNodeName().equals("合同退款申请初审不通过")) {
                refund.setBusinessState(4);
            }
            refund.setFlowNumber(approvalFlow.getFlowNumber());
            refund.setFlowNodeId(endNode.getId());
            refund.setFlowNodeName(endNode.getNodeName());
            refund.setRemark(item.getRemark());
            refund.setDelFlag(1);
            mySqlMapper.insertRefund(refund);

            // 历史记录
            List<ApprovalRecord> records = new ArrayList<>();
            List<OracleApprovalRecord> oracleApprovalRecords =
                    applyMapper.selectApprovalRecords_8(item.getAppId());
            if (oracleApprovalRecords != null && oracleApprovalRecords.size() > 0
                    && oracleApprovalRecords.get(0) != null
                    && !StringUtils.isEmpty(oracleApprovalRecords.get(0).getNodeName())) {
                for (OracleApprovalRecord oracleApprovalRecord : oracleApprovalRecords) {
                    ApprovalRecord record = new ApprovalRecord();
                    record.setBusinessNumber(item.getBusinessNumber());
                    record.setFlowNumber(approvalFlow.getFlowNumber());
                    record.setNodeId(endNode.getId());
                    if (!StringUtils.isEmpty(oracleApprovalRecord.getNodeName())) {
                        record.setNodeName(oracleApprovalRecord.getNodeName());
                    }
                    record.setApprover(oracleApprovalRecord.getApprover());
                    record.setApprovalTime(oracleApprovalRecord.getApprovalTime());
                    record.setTableId(refund.getId());
                    if (oracleApprovalRecord.getApprovalStatus() != null) {
                        record.setApprovalStatus(1);
                    }
                    record.setApprovalRemark(oracleApprovalRecord.getRemark());
                    records.add(record);
                }
                flowMapper.insertRecordBatch(records);
            }

        }
        System.out.println(">>>>>>>>>>>>>>>>>>" + "导入退款记录执行结束，用时："
                + (System.currentTimeMillis() - startTime) + "ms");
    }
}
